#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

import logging
from importlib import import_module

from pyams_portal.interfaces import IPortalTemplateContainer
from pyams_portal.template import PortalTemplateContainer
from pyams_utils.interfaces.site import ISiteGenerations
from pyams_utils.registry import utility_config
from pyams_utils.site import check_required_utilities


logger = logging.getLogger("PyAMS (portal)")


REQUIRED_UTILITIES = ((IPortalTemplateContainer, '', PortalTemplateContainer, 'Portal templates'), )


@utility_config(name='PyAMS portal', provides=ISiteGenerations)
class PortalGenerationsChecker(object):
    """PyAMS portal package generations checker"""

    order = 70
    generation = 2

    def evolve(self, site, current=None):
        """Check for required utilities, tables and tools"""
        if not current:
            current = 1
        check_required_utilities(site, REQUIRED_UTILITIES)
        for generation in range(current, self.generation):
            module_name = 'pyams_portal.generations.evolve{}'.format(generation)
            module = import_module(module_name)
            module.evolve(site)
